# Unscrambler

* Sample code to test python packaging.
* Python tool to find words from scrambled letters, cos I wanted to solve scramble in Deccan Chronicle.
* Returns a list of words that can be formed using all the letters in the scrambled word.
* Uses Wordnet to get complete vocabulary.
